import * as fs from "fs";

export class FileHandler {
    public static saveBase64Photo(data: string): Promise<string> {
        return new Promise((resolve, reject) => {
            try {
                // Entferne das Präfix "data:image/jpeg;base64,"
                const base64Data = data.replace(/^data:image\/jpeg;base64,/, '');

                // Konvertiere den Base64-String in ein Buffer-Objekt
                const imageBuffer = Buffer.from(base64Data, 'base64');

                const date = new Date(); // cap_2022-06-07T23_02_23.jpeg
                const filename = "cap_" + date.getFullYear() + "-" + (date.getMonth() + 1) + "-" + date.getDate() + "T" + date.getHours() + "_" + date.getMinutes() + "_" + date.getSeconds() + ".jpeg";

                try {
                    fs.mkdirSync("./images/");
                } catch (e) {
                }

                // Speichere den Buffer als JPEG-Datei
                fs.writeFile("./images/" + filename, imageBuffer, (err) => {
                    if (err) {
                        console.error('Error on saving image', err);
                        reject(err);
                    } else {
                        console.log('Image saved as: ', filename);
                        resolve(filename);
                    }
                });
            } catch (e) {
                reject(e);
            }
        });

    }

    public static getLastImages(): Promise<{ image: string, locked: boolean }[]> {
        return new Promise(async (resolve, reject) => {
            let files = await this.getSortedFiles("./images/");
            console.log(files);
            let i = 0;
            let data: { image: string, locked: boolean }[] = [];
            for (let file of files) {
                if (i == 7) break;

                let d = await fs.promises.readFile("./images/" + file);
                let locked = ((await fs.promises.stat("./images/" + file)).birthtime.getTime() + 30000 < Date.now());
                data.push({image: "data:image/jpeg;base64," + d.toString("base64"), locked: locked});
                i++;
            }

            resolve(data);
        });
    }

    public static getTempPicture() {
        return "data:image/jpeg;base64," + (fs.readFileSync('./temp/picture.jpg').toString("base64"));
    }

    public static deleteLastImage() {
        return new Promise(async resolve => {
            let files = await this.getSortedFiles("./images/");
            await fs.promises.unlink("./images/" + files[0]);
        });

    }

    private static getSortedFiles(dir: string): Promise<string[]> {
        return new Promise(async (resolve, reject) => {
            const files = await fs.promises.readdir(dir);

            resolve(files
                .map(fileName => ({
                    name: fileName,
                    time: fs.statSync(`${dir}/${fileName}`).mtime.getTime(),
                }))
                .sort((a, b) => a.time - b.time)
                .reverse()
                .map(file => file.name)
                .filter((element) => element.startsWith("cap_") )
            );
        });
    }
}