import {app, BrowserWindow} from "electron";
import * as path from "path";
import {Server} from "./server";
import * as process from "process";
import {GPIO} from "./gpio";
import {PythonWebcam} from "./python_webcam";
import {FileHandler} from "./file_handler";
import {Utils} from "./utils";

function createWindow() {
    // Create the browser window.
    const mainWindow = new BrowserWindow({
        height: 1080,
        webPreferences: {
            preload: path.join(__dirname, "preload.js"),
        },
        width: 1920,
        fullscreenable: true,
        fullscreen: true,
        closable: true,
        autoHideMenuBar: true,
    });

    // and load the index.html of the app.
    mainWindow.loadFile(path.join(__dirname, "../html/index.html"));

    // Open the DevTools.
    //mainWindow.webContents.openDevTools();
}

// This method will be called when Electron has finished
// initialization and is ready to create browser windows.
// Some APIs can only be used after this event occurs.
app.whenReady().then(() => {
    createWindow();
});

// Quit when all windows are closed, except on macOS. There, it's common
// for applications and their menu bar to stay active until the user quits
// explicitly with Cmd + Q.
app.on("window-all-closed", () => {
    app.quit();
});

// In this file you can include the rest of your app"s specific main process
// code. You can also put them in separate files and require them here.

Server.initServer().then();

PythonWebcam.startPythonService();

/*setInterval(() => {
    capture()
}, 1000*10);*/


try {
    Utils.load();

    // Capture button
    GPIO.watchForButton(10, (pin) => {
        Utils.capture()
    });

    // Delete button
    GPIO.watchForButton(11, (pin) => {
        console.log("Delete fired!");
        Utils.delete_last();

    });
} catch (e) {
    console.error("Could not bind gpio ports");
}

process.on("SIGINT", _ => {
    GPIO.unexportAll();
});

