import * as child_process from "child_process";
import {FileHandler} from "./file_handler";
import {Server} from "./server";

const {spawn} = require('node:child_process');


export class PythonWebcam {
    private static filename = __dirname + "/../capture.py";
    private static waitFor = "wrote_frame";
    private static calls: Function[] = [];
    public static noCamera = true;

    private static process: child_process.ChildProcess;

    public static startPythonService() {
        this.process = spawn("python", [this.filename], {stdio: 'pipe'});
        this.process.stdout.setEncoding('utf-8');

        this.process.stdout.on('data', (data) => {
            this.noCamera = false;
            const line = data.trim().split('\n')[0].replace(/\r?\n|\r/gm, "").replace("\n", '');
            if (line.startsWith(this.waitFor.trim())) {
                for (let c of this.calls) {
                    c();
                }
                this.calls = [];
            }

        });

        this.process.on("exit", (code) => {
            console.log("Subprocess exited! " + code)
            this.noCamera = true;
            if (code != 0)
            {
                //throw new Error("Could not open camera device/script - Code: " + code.toString());
            }

        });
    }

    public static getImage(): Promise<String | Buffer> {
        return new Promise((resolve, reject) => {
            if( this.calls.length > 1 )
            {
                return reject("Already capturing!");
            }
            this.waitForScriptFrame(() => {
                resolve(FileHandler.getTempPicture());
            });
            setTimeout(() => resolve(""), 1000 );
        });
    }

    public static captureImage(): Promise<string> {
        return new Promise(async (resolve, reject) => {
            let img = (await this.getImage()).toString();
            if(img.length != 0 )
                await FileHandler.saveBase64Photo(img);
            resolve(img);
            await Server.sendRecentPhotos();
        });
    }

    private static waitForScriptFrame(callback: () => void) {
        if(this.noCamera)
        {
            return;
        }

        this.calls.push(callback);
    }
}