import {Socket} from "socket.io";
import {FileHandler} from "./file_handler";
import {PythonWebcam} from "./python_webcam";

import {Utils} from "./utils";

export class Server {
    private static app = require("express")();
    private static server = require('http').createServer(this.app);
    public static io = require('socket.io')(this.server);

    public static initServer(): Promise<void> {
        return new Promise((resolve, reject) => {
            // Socket.IO-Verbindung herstellen
            this.io.on('connection', async (socket: Socket) => {
                console.log('Client connected');
                await this.sendRecentPhotos();

                socket.on("do_shot", () => {
                    console.log("Capture fired!");
                    Utils.capture();
                });
                socket.on("do_delete", () => {
                    Utils.delete_last();
                })

            });



            //Webcam.startCameraStream();
            this.server.listen(3000);

            this.nextInterval();
        });

    }

    public static async sendRecentPhotos()
    {
        let lastImages = await FileHandler.getLastImages();
        console.log("Sending last shots... " );
        this.io.emit('last_shots', lastImages);
    }


    public static nextInterval(){
        setTimeout(async () => {
            try {
                if( PythonWebcam.noCamera )
                {
                    this.io.emit("no_camera");
                } else
                {
                    this.io.emit("stream", (await PythonWebcam.getImage()));
                }

            } catch( e )
            {
            }
            this.nextInterval();
        }, 1000/30);
    }


}