import {FSWebcam, ImageSnapWebcam, WebcamOptions, WindowsWebcam} from "node-webcam";
import * as fs from "fs";
import {FileHandler} from "./file_handler";
import {Server} from "./server";

const NodeWebcam = require("node-webcam");

export class Webcam {
    // Konfiguriere Kamera
    private static videoDevice = '/dev/video0';
    private static camera: ImageSnapWebcam | FSWebcam | WindowsWebcam = null;
    private static width = 1280;
    private static height = 720;


    public static startCameraStream() {
        const webcamOptions = {
            width: this.width,
            height: this.height,
            quality: 100,
            output: "jpeg",
            callbackReturn: "base64",
            verbose: false,
            device: this.videoDevice
        } as WebcamOptions;
        this.camera = NodeWebcam.create(webcamOptions);
    }

    public static getImage(): Promise<String | Buffer> {
        return new Promise(resolve => {
            if( !fs.existsSync("./temp/") )
                fs.mkdirSync("./temp/");

            this.camera.capture("./temp/picture.jpg", function (err, data) {
                if (!err) {
                    resolve(data);
                } else {
                    console.error("Error on webcam capture: ", err);
                }
            });
        });
    }

    public static captureImage(): Promise<string>
    {
        return new Promise(async (resolve,reject) => {
            let img = (await this.getImage() ).toString();
            await FileHandler.saveBase64Photo(img);
            resolve(img);
            await Server.sendRecentPhotos();
        });
    }



}
